==> ejc-proequipmentcorp-impl-3.0.0-20221027.061535-68-sources.jar: com/ejianc/business/proequipmentcorpout/contract/service/impl/OutRentContractRelieveBpmServiceImpl.java <==
package com.ejianc.business.proequipmentcorpout.contract.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.business.proequipmentcorpout.contract.bean.OutRentContractEntity;
import com.ejianc.business.proequipmentcorpout.contract.bean.OutRentContractRelieveEntity;
import com.ejianc.business.proequipmentcorpout.contract.enums.PerformanceStatusEnum;
import com.ejianc.business.proequipmentcorpout.contract.service.IOutRentContractRelieveService;
import com.ejianc.business.proequipmentcorpout.contract.service.IOutRentContractService;
import com.ejianc.business.proequipmentcorpout.contract.vo.OutRentContractVO;
import com.ejianc.business.targetcost.api.IExecutionApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;

import java.util.Date;
import java.util.List;

@Service("outRentContractRelieve") 
public class OutRentContractRelieveBpmServiceImpl implements ICommonBusinessService {
	@Autowired
	private IOutRentContractRelieveService service;
	@Autowired
	private SessionManager sessionManager;
	@Autowired
	private IBillTypeApi billTypeApi;
	@Autowired
	private IExecutionApi executionApi;
	@Autowired
	private IOutRentContractService outRentContractService;
	private Logger logger = LoggerFactory.getLogger(this.getClass());

	/**
	 * 提交前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		OutRentContractRelieveEntity e = service.selectById(billId);
		UserContext userContext = sessionManager.getUserContext();
		e.setCommitDate(new Date());
		e.setCommitUserCode(userContext.getUserCode());
		e.setCommitUserName(userContext.getUserName());
		logger.info("======提交完回调======,{}", JSONObject.toJSONString(e));
		service.saveOrUpdate(e, false);
		return CommonResponse.success("合同解除审批回调处理成功");
	}

	/**
	 * 有审批流的撤回前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
		return bpmBackCheck(billId, state, billTypeCode);
	};

	/**
	 * 有审批流的撤回后回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		OutRentContractRelieveEntity entity = service.selectById(billId);
		if (entity != null) {
			// 已签章
			if (entity.getDraftType() == 2) {
				entity.setSignatureState("4");
				entity.setPerformanceStatus(PerformanceStatusEnum.已作废.getCode());
				entity.setEffectiveDate(new Date());
				service.saveOrUpdate(entity, false);

				QueryParam param = new QueryParam();
				param.getParams().put("id", new Parameter(QueryParam.EQ, entity.getContractId()));
				List<OutRentContractEntity> contractEntities = outRentContractService.queryList(param, false);
				contractEntities.get(0).setContractPerformanceState(PerformanceStatusEnum.已作废.getCode());
				logger.info("======终审审核完回调,已签章======,{}", JSONObject.toJSONString(contractEntities.get(0)));
				outRentContractService.saveOrUpdate(contractEntities.get(0), false);

//				// 推送目标成本
//				CommonResponse<String> response = executionApi.aggPush(service.targetCost(entity));
//				logger.info("推送目标成本入参：" + JSONObject.toJSONString(service.targetCost(entity)));
//				if (!response.isSuccess()){
//					logger.error("推送目标成本失败: , {}", response.getMsg());
//					throw new BusinessException(response.getMsg());
//				}


				// 推送合同池
//				outRentContractService.pushContract(BeanMapper.map(contractEntities.get(0), OutRentContractVO.class));
			} else if (entity.getDraftType() == 1) {
				// 初始化成未签章
				entity.setSignatureState("1");
				logger.info("======终审审核完回调,初始化成未签章======,{}", JSONObject.toJSONString(entity));
				service.saveOrUpdate(entity, false);
			}
		}

		return CommonResponse.success("合同解除终审审核完回调处理成功!");
	}

	/**
	 * 弃审前事件回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	private CommonResponse<String> bpmBackCheck(Long billId, Integer state, String billTypeCode) {

		OutRentContractRelieveEntity entity = service.selectById(billId);

		//合同是否被其他单据引用
		CommonResponse<String> res = billTypeApi.checkQuote(billTypeCode, billId);
		logger.info("平台返回查询被引用情况" + res.isSuccess() + "----" + res.getMsg());

		if (!res.isSuccess()) {
			return CommonResponse.error("当前单据已被下游业务引用，不能撤回！");
		}

		// 签章状态：1、未签章；2、待乙方签章；3、待甲方签章；4、已签章；  单据新增后默认为未签章
		if("4".equals(entity.getSignatureState())){
			return CommonResponse.error("合同解除已生效，不允许弃审!");
		}

		return CommonResponse.success("撤回前校验回调成功！");
	}

}

==> ejc-proequipmentcorp-impl-3.0.0-20221220.151353-256-sources.jar: com/ejianc/business/proequipmentcorpout/contract/service/impl/OutRentContractRelieveBpmServiceImpl.java <==
package com.ejianc.business.proequipmentcorpout.contract.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.business.proequipmentcorpout.contract.bean.OutRentContractEntity;
import com.ejianc.business.proequipmentcorpout.contract.bean.OutRentContractRelieveEntity;
import com.ejianc.business.proequipmentcorpout.constants.OutRentConstants;
import com.ejianc.business.proequipmentcorpout.contract.enums.PerformanceStatusEnum;
import com.ejianc.business.proequipmentcorpout.contract.service.IOutRentContractRelieveService;
import com.ejianc.business.proequipmentcorpout.contract.service.IOutRentContractService;
import com.ejianc.business.targetcost.api.IExecutionApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;

import java.util.Date;
import java.util.List;

@Service("outRentContractRelieve") 
public class OutRentContractRelieveBpmServiceImpl implements ICommonBusinessService {
	@Autowired
	private IOutRentContractRelieveService service;
	@Autowired
	private SessionManager sessionManager;
	@Autowired
	private IBillTypeApi billTypeApi;
	@Autowired
	private IExecutionApi executionApi;
	@Autowired
	private IOutRentContractService outRentContractService;
	private Logger logger = LoggerFactory.getLogger(this.getClass());

	/**
	 * 提交前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		OutRentContractRelieveEntity e = service.selectById(billId);
		UserContext userContext = sessionManager.getUserContext();
		e.setCommitDate(new Date());
		e.setCommitUserCode(userContext.getUserCode());
		e.setCommitUserName(userContext.getUserName());
		logger.info("======提交完回调======,{}", JSONObject.toJSONString(e));
		service.saveOrUpdate(e, false);
		return CommonResponse.success("合同解除审批回调处理成功");
	}

	/**
	 * 有审批流的撤回前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
		return bpmBackCheck(billId, state, billTypeCode);
	};

	/**
	 * 有审批流的撤回后回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		OutRentContractRelieveEntity entity = service.selectById(billId);
		if (entity != null) {
			// 已签章
			if (entity.getDraftType() == 2) {
				entity.setSignatureState("4");
				entity.setPerformanceStatus(PerformanceStatusEnum.已作废.getCode());
				entity.setEffectiveDate(new Date());
				service.saveOrUpdate(entity, false);

				QueryParam param = new QueryParam();
				param.getParams().put("id", new Parameter(QueryParam.EQ, entity.getContractId()));
				List<OutRentContractEntity> contractEntities = outRentContractService.queryList(param, false);
				contractEntities.get(0).setContractPerformanceState(PerformanceStatusEnum.已作废.getCode());
				logger.info("======终审审核完回调,已签章======,{}", JSONObject.toJSONString(contractEntities.get(0)));
				outRentContractService.saveOrUpdate(contractEntities.get(0), false);

//				// 推送目标成本
//				CommonResponse<String> response = executionApi.aggPush(service.targetCost(entity));
//				logger.info("推送目标成本入参：" + JSONObject.toJSONString(service.targetCost(entity)));
//				if (!response.isSuccess()){
//					logger.error("推送目标成本失败: , {}", response.getMsg());
//					throw new BusinessException(response.getMsg());
//				}

				outRentContractService.pushContractToRent(JSONObject.toJSONString(entity),
						OutRentConstants.PUSH_RENT_OPT_TYPE_ADD, OutRentConstants.PUSH_RENT_OPT_BILL_CONTRACT_RELIEVE);
				// 推送合同池
//				outRentContractService.pushContract(BeanMapper.map(contractEntities.get(0), OutRentContractVO.class));
			} else if (entity.getDraftType() == 1) {
				// 初始化成未签章
				entity.setSignatureState("1");
				logger.info("======终审审核完回调,初始化成未签章======,{}", JSONObject.toJSONString(entity));
				service.saveOrUpdate(entity, false);
			}
		}

		return CommonResponse.success("合同解除终审审核完回调处理成功!");
	}

	/**
	 * 弃审前事件回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	private CommonResponse<String> bpmBackCheck(Long billId, Integer state, String billTypeCode) {

		OutRentContractRelieveEntity entity = service.selectById(billId);

		//合同是否被其他单据引用
		CommonResponse<String> res = billTypeApi.checkQuote(billTypeCode, billId);
		logger.info("平台返回查询被引用情况" + res.isSuccess() + "----" + res.getMsg());

		if (!res.isSuccess()) {
			return CommonResponse.error("当前单据已被下游业务引用，不能撤回！");
		}

		// 签章状态：1、未签章；2、待乙方签章；3、待甲方签章；4、已签章；  单据新增后默认为未签章
		if("4".equals(entity.getSignatureState())){
			return CommonResponse.error("合同解除已生效，不允许弃审!");
		}
		outRentContractService.pushContractToRent(JSONObject.toJSONString(entity),
				OutRentConstants.PUSH_RENT_OPT_TYPE_DEL, OutRentConstants.PUSH_RENT_OPT_BILL_CONTRACT_RELIEVE);
		return CommonResponse.success("撤回前校验回调成功！");
	}

}
